"use strict";

var __assign = void 0 && (void 0).__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
      }
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});

var react_1 = __importDefault(require("react"));

var react_dom_1 = __importDefault(require("react-dom"));

var react_redux_1 = require("react-redux");

var react_intl_1 = require("react-intl");

var classnames_1 = __importDefault(require("classnames"));

var Button_1 = __importDefault(require("../Button"));

var CheckBox_1 = __importDefault(require("../CheckBox"));

var useDialog_1 = require("./useDialog");

require("./dialog.less");

var CheckBox = CheckBox_1["default"].CheckBox;

var Dialog = function Dialog(props, ref) {
  var _a, _b;

  var title = props.title,
      _c = props.className,
      className = _c === void 0 ? '' : _c,
      _d = props.style,
      style = _d === void 0 ? {} : _d,
      _e = props.prefixCls,
      prefixCls = _e === void 0 ? 'ult' : _e,
      titleNone = props.titleNone,
      buttonNone = props.buttonNone,
      _f = props.abortType,
      abortType = _f === void 0 ? 'default' : _f,
      _g = props.confirmType,
      confirmType = _g === void 0 ? 'primary' : _g,
      _h = props.confirmClassName,
      confirmClassName = _h === void 0 ? '' : _h,
      _j = props.twiceConfirm,
      twiceConfirm = _j === void 0 ? false : _j,
      children = props.children;

  var _k = useDialog_1.useDialog(props, ref),
      dialogRef = _k.dialogRef,
      abortBtnRef = _k.abortBtnRef,
      confirmBtnRef = _k.confirmBtnRef,
      handleClose = _k.handleClose,
      handleAbort = _k.handleAbort,
      handleConfirm = _k.handleConfirm,
      handleTwiceConfirm = _k.handleTwiceConfirm,
      confirmDisable = _k.confirmDisable,
      checked = _k.checked,
      confirmTitleState = _k.confirmTitleState,
      abortTitle = _k.abortTitle,
      twiceConfirmLabel = _k.twiceConfirmLabel,
      bottomLeftState = _k.bottomLeftState,
      approveDisabledState = _k.approveDisabledState,
      confirming = _k.confirming;

  return react_1["default"].createElement("div", {
    ref: dialogRef,
    className: classnames_1["default"](prefixCls + "-ui-dialog", className),
    style: style
  }, titleNone ? null : react_1["default"].createElement("div", {
    className: classnames_1["default"](prefixCls + "-ui-dialog-header")
  }, typeof title === 'string' ? react_1["default"].createElement("h3", null, title) : title), react_1["default"].createElement("a", {
    className: classnames_1["default"](prefixCls + "-ui-dialog-close")
  }, " ", react_1["default"].createElement("i", {
    className: "iconfont icon-error",
    onClick: handleClose
  })), react_1["default"].createElement("div", {
    className: classnames_1["default"](prefixCls + "-ui-dialog-content")
  }, react_1["default"].cloneElement(children)), buttonNone ? null : react_1["default"].createElement("div", {
    className: classnames_1["default"](prefixCls + "-ui-dialog-btn", (_a = {}, _a[prefixCls + "-ui-dialog-btn-between"] = twiceConfirm, _a), (_b = {}, _b[prefixCls + "-ui-dialog-btn-between"] = bottomLeftState, _b))
  }, twiceConfirm ? react_1["default"].createElement(CheckBox, {
    name: "twiceConfirm",
    title: twiceConfirmLabel,
    checked: checked,
    onToggle: handleTwiceConfirm
  }) : null, bottomLeftState || null, react_1["default"].createElement("div", null, abortTitle ? react_1["default"].createElement(Button_1["default"], {
    ref: abortBtnRef,
    className: classnames_1["default"]({
      hidden: !abortTitle
    }),
    onClick: handleAbort,
    type: abortType
  }, abortTitle) : null, confirmTitleState ? react_1["default"].createElement(Button_1["default"], {
    ref: confirmBtnRef,
    loading: confirming,
    iconRight: true,
    onClick: handleConfirm,
    type: confirmType,
    disabled: confirming || approveDisabledState || confirmDisable || twiceConfirm && !checked,
    className: confirmClassName
  }, confirmTitleState) : null)));
};

var RefDialog = react_1["default"].forwardRef(Dialog);
var INTL_LOCALE = {
  'en': 'en',
  'zh_CN': 'zh'
};

function createDialog(el, props) {
  var prefixCls = 'ult';
  props = props || {};
  var wrapper = document.createElement('div');
  var modal = react_1["default"].createRef();
  wrapper.className = prefixCls + "-ui-dialog-wrap";
  wrapper.style.height = '100vh';
  wrapper.style.width = '100vw';
  wrapper = document.body.appendChild(wrapper);

  var cleanup = function cleanup() {
    react_dom_1["default"].unmountComponentAtNode(wrapper);
    setTimeout(function () {
      document.body.removeChild(wrapper); // wrapper.remove()
    }, 0);
  };

  var abort = props.abort;

  props.abort = function () {
    if (!abort) {
      cleanup();
    }

    if (abort) {
      if (abort.call(this) !== false) {
        cleanup();
      }
    }
  }; // const close = props.close


  props.close = function () {
    cleanup();
  };

  var confirm = props.confirm;

  props.confirm = function () {
    if (!confirm) {
      cleanup();
      return;
    }

    var confirmRes = confirm.call(this);

    if (confirmRes && confirmRes.then && typeof confirmRes.then === 'function') {
      confirmRes.then(function (res) {
        if (res !== false) {
          cleanup();
        }
      });
      return confirmRes;
    } else if (confirmRes !== false) {
      cleanup();
    }
  }; // bottomLeft, confirmDisable


  var update = function update(state) {
    if (modal === undefined || modal.current === undefined || modal.current === null) {
      return;
    }

    if (state.confirmDisable !== undefined) {
      modal.current.setConfirmDisable(state.confirmDisable);
    }

    if (state.bottomLeft !== undefined) {
      modal.current.setBottomLeftState(state.bottomLeft);
    }

    if (state.approveDisabled !== undefined) {
      modal.current.setApproveDisabledState(state.approveDisabled);
    }
  };

  var messages = window.LanguageData[window.LangCode];
  react_dom_1["default"].render(react_1["default"].createElement(react_redux_1.Provider, {
    store: window.ReducerStore || {}
  }, react_1["default"].createElement(react_intl_1.IntlProvider, {
    locale: INTL_LOCALE[window.LangCode],
    messages: messages
  }, react_1["default"].createElement(RefDialog, __assign({
    ref: modal
  }, props), el))), wrapper);
  return {
    wrapper: wrapper,
    cleanup: cleanup,
    update: update,
    props: props
  };
}

exports["default"] = createDialog;