"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDialog = void 0;

var react_1 = require("react");

var INTL_LOCALE = {
  'en': 'en',
  'zh_CN': 'zh'
};
var i18nMap = {
  cancel: {
    en: 'Cancel',
    zh: '取消'
  },
  confirm: {
    en: 'Confirm',
    zh: '确定'
  },
  confirmDel: {
    en: 'Confirm Delete',
    zh: '确认删除'
  }
};
var locale = INTL_LOCALE[window.LangCode] || 'en';

exports.useDialog = function (_a, ref) {
  var _b = _a.countDown,
      countDown = _b === void 0 ? 0 : _b,
      _c = _a.confirmTitle,
      confirmTitle = _c === void 0 ? i18nMap.confirm[locale] : _c,
      _d = _a.confirmingTitle,
      confirmingTitle = _d === void 0 ? '' : _d,
      _e = _a.abortTitle,
      abortTitle = _e === void 0 ? i18nMap.cancel[locale] : _e,
      _f = _a.twiceConfirmLabel,
      twiceConfirmLabel = _f === void 0 ? i18nMap.confirmDel[locale] : _f,
      close = _a.close,
      confirm = _a.confirm,
      abort = _a.abort,
      _g = _a.bottomLeft,
      bottomLeft = _g === void 0 ? '' : _g,
      _h = _a.approveDisabled,
      approveDisabled = _h === void 0 ? false : _h;

  var _j = react_1.useState(false),
      checked = _j[0],
      setChecked = _j[1];

  var _k = react_1.useState(countDown > 0),
      confirmDisable = _k[0],
      setConfirmDisable = _k[1];

  var _l = react_1.useState(countDown > 0 ? confirmTitle + " (" + countDown + ")" : confirmTitle),
      confirmTitleState = _l[0],
      setConfirmTitleState = _l[1];

  var _m = react_1.useState(bottomLeft),
      bottomLeftState = _m[0],
      setBottomLeftState = _m[1];

  var _o = react_1.useState(approveDisabled),
      approveDisabledState = _o[0],
      setApproveDisabledState = _o[1];

  var _p = react_1.useState(false),
      confirming = _p[0],
      setConfirming = _p[1];

  var dialogRef = react_1.useRef();
  var abortBtnRef = react_1.useRef();
  var confirmBtnRef = react_1.useRef();
  react_1.useImperativeHandle(ref, function () {
    return {
      setConfirmDisable: setConfirmDisable,
      setBottomLeftState: setBottomLeftState,
      setApproveDisabledState: setApproveDisabledState
    };
  });
  react_1.useEffect(function () {
    if (countDown > 0) {
      countTimer();
    }

    if (confirmBtnRef.current) {
      confirmBtnRef.current.focus();
    } else if (abortBtnRef.current) {
      abortBtnRef.current.focus();
    }

    return function () {
      if (timer) {
        clearInterval(timer);
      }
    };
  }, []);
  var timer;

  var countTimer = function countTimer() {
    var _countDown = countDown;
    timer = setInterval(function () {
      if (_countDown > 0) {
        _countDown--;
        setConfirmTitleState(confirmTitle + " (" + _countDown + ")");
      } else {
        setConfirmTitleState(confirmTitle);
        setConfirmDisable(false);
        clearInterval(timer);
      }
    }, 1000);
  };

  var handleClose = function handleClose() {
    if (typeof close === 'function') {
      close();
    }
  };

  var handleAbort = function handleAbort() {
    if (typeof abort === 'function') {
      abort();
    }
  };

  var handleConfirm = function handleConfirm() {
    if (typeof confirm === 'function') {
      var res = confirm();

      if (res && res.then && typeof res.then === 'function') {
        setConfirming(true);
        confirmingTitle && setConfirmTitleState(confirmingTitle);
        res.then(function (close) {
          if (close === false) {
            setConfirming(false);
            setConfirmTitleState(confirmTitle);
          }
        })["catch"](function () {
          setConfirming(false);
          setConfirmTitleState(confirmTitle);
        });
      }
    }
  };

  var handleTwiceConfirm = function handleTwiceConfirm(checked) {
    setChecked(checked);
  };

  return {
    dialogRef: dialogRef,
    abortBtnRef: abortBtnRef,
    confirmBtnRef: confirmBtnRef,
    handleClose: handleClose,
    handleAbort: handleAbort,
    handleConfirm: handleConfirm,
    handleTwiceConfirm: handleTwiceConfirm,
    confirmDisable: confirmDisable,
    checked: checked,
    confirmTitleState: confirmTitleState,
    abortTitle: abortTitle,
    twiceConfirmLabel: twiceConfirmLabel,
    bottomLeftState: bottomLeftState,
    approveDisabledState: approveDisabledState,
    confirming: confirming
  };
};