"use strict";

var __assign = void 0 && (void 0).__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
      }
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDropdownMenuItem = exports.useDropdownMenu = exports.useDropdown = void 0;

var react_1 = require("react");

var lodash_1 = require("lodash");

var uuid_1 = __importDefault(require("uuid"));

exports.useDropdown = function (_a) {
  var _b = _a.options,
      options = _b === void 0 ? [] : _b,
      _c = _a.selectable,
      selectable = _c === void 0 ? false : _c;

  var _d = react_1.useState(options),
      optionsState = _d[0],
      setOptionsState = _d[1];

  var _e = react_1.useState(false),
      isExpanded = _e[0],
      setIsExpanded = _e[1];

  var uniqueID = react_1.useRef(uuid_1["default"].v4());

  var handleCollapse = function handleCollapse(e) {
    if (e.id !== uniqueID.current) {
      setIsExpanded(false);
    }
  };

  var handleToggle = function handleToggle(e) {
    e.preventDefault();
    e.nativeEvent.stopImmediatePropagation(); // Dispatch 自定义事件，通过这个方式确保页面只有一个dropdown弹出

    var evt = document.createEvent('Event');
    evt.id = uniqueID.current;
    evt.initEvent('click', true, true);
    document.dispatchEvent(evt);
    setIsExpanded(!isExpanded);
  };

  var handleHover = function handleHover(e, isExpanded) {
    e.preventDefault();
    e.nativeEvent.stopImmediatePropagation();
    setIsExpanded(isExpanded);
  };

  var handleClick = function handleClick(callback, name, e) {
    if (selectable) {
      setOptionsState(optionsState.map(function (item) {
        return __assign(__assign({}, item), {
          selected: item.name === name
        });
      }));
    }

    if (typeof callback === 'function') {
      callback(e, name);
    }
  };

  react_1.useEffect(function () {
    document.addEventListener('click', handleCollapse);
    return function () {
      document.removeEventListener('click', handleCollapse);
    };
  }, []);
  react_1.useEffect(function () {
    if (!lodash_1.isEqual(options, optionsState)) {
      setOptionsState(options);
    }
  }, [options]);
  return {
    uniqueID: uniqueID,
    isExpanded: isExpanded,
    handleToggle: handleToggle,
    handleCollapse: handleCollapse,
    optionsState: optionsState,
    handleHover: handleHover,
    handleClick: handleClick
  };
};

exports.useDropdownMenu = function (_a) {
  var icon = _a.icon,
      isExpanded = _a.isExpanded,
      _b = _a.trigger,
      trigger = _b === void 0 ? 'click' : _b,
      onHover = _a.onHover,
      onToggle = _a.onToggle;

  var _c = react_1.useState(icon || (isExpanded ? 'up' : 'down')),
      titleIcon = _c[0],
      setTitleIcon = _c[1];

  var handleMouseEnter = function handleMouseEnter(e) {
    trigger === 'hover' && onHover(e, true);
  };

  var handleMouseLeave = function handleMouseLeave(e) {
    trigger === 'hover' && onHover(e, false);
  };

  var handleTitleClick = function handleTitleClick(e) {
    trigger !== 'hover' && onToggle(e);
  };

  react_1.useEffect(function () {
    if (!icon) {
      setTitleIcon(isExpanded ? 'up' : 'down');
    }
  }, [isExpanded]);
  return {
    titleIcon: titleIcon,
    handleMouseEnter: handleMouseEnter,
    handleMouseLeave: handleMouseLeave,
    handleTitleClick: handleTitleClick
  };
};

exports.useDropdownMenuItem = function (_a) {
  var disabled = _a.disabled,
      collapse = _a.collapse,
      onClick = _a.onClick,
      _b = _a.href,
      href = _b === void 0 ? '#!' : _b,
      _c = _a.target,
      target = _c === void 0 ? 'self' : _c;

  var handleClick = function handleClick(e) {
    if (href && href !== '#!') {
      window.open(href, "_" + target);
      return;
    }

    if (disabled) {
      e.nativeEvent.stopImmediatePropagation();
      return;
    }

    collapse(e);
    onClick(e);
  };

  var handleClickSubItem = function handleClickSubItem(disabled, callback, name, href, target, e) {
    if (href && href !== '#!') {
      window.open(href, "_" + target);
      return;
    }

    if (disabled) {
      e.nativeEvent.stopImmediatePropagation();
      return;
    }

    collapse(e);

    if (typeof callback === 'function') {
      callback(e, name);
    }
  };

  return {
    handleClick: handleClick,
    handleClickSubItem: handleClickSubItem
  };
};