"use strict";

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInputNum = void 0;

var react_1 = require("react");

var language_1 = __importDefault(require("./language"));

function defaultParser(input) {
  return input.replace(/[^\w\.-]+/g, '');
}

var maxNumber = Number.MAX_SAFE_INTEGER || 9007199254740991;

exports.useInputNum = function (_a) {
  var value = _a.value,
      defaultValue = _a.defaultValue,
      _b = _a.precision,
      precision = _b === void 0 ? 6 : _b,
      _c = _a.disabled,
      disabled = _c === void 0 ? false : _c,
      _d = _a.step,
      step = _d === void 0 ? 1 : _d,
      _e = _a.min,
      min = _e === void 0 ? -maxNumber : _e,
      _f = _a.max,
      max = _f === void 0 ? maxNumber : _f,
      onError = _a.onError,
      _g = _a.required,
      required = _g === void 0 ? false : _g,
      _h = _a.onChange,
      onChange = _h === void 0 ? function () {} : _h,
      _j = _a.onKeyDown,
      onKeyDown = _j === void 0 ? function () {} : _j,
      _k = _a.parser,
      parser = _k === void 0 ? defaultParser : _k;

  var _l = react_1.useState(false),
      isMinDisable = _l[0],
      setIsMinDisable = _l[1];

  var _m = react_1.useState(false),
      isMaxDisable = _m[0],
      setIsMaxDisable = _m[1];

  var _o = react_1.useState(false),
      error = _o[0],
      setError = _o[1];

  var _p = react_1.useState(''),
      inputValue = _p[0],
      setInputValue = _p[1];

  var _q = react_1.useState(false),
      isFocused = _q[0],
      setIsFocused = _q[1];

  var handleStep = function handleStep(factor, e) {
    e.preventDefault();

    if (disabled) {
      return;
    }

    var val = inputValue;

    if (val === '' || val === null || val === undefined || isNaN(val)) {
      val = 0;
    }

    val = val + step * factor;
    val = Math.min(Math.max(min, val), max);
    handleDealValue(val);
    setIsFocused(true);
  };

  var isValid = function isValid(val) {
    return val >= min && val <= max;
  };

  var getErrorMessage = function getErrorMessage(v) {
    return v > max ? language_1["default"][window.LangCode]['TooLarge'] : language_1["default"][window.LangCode]['TooSmall'];
  };

  var handleDealValue = function handleDealValue(v) {
    handleDealError(v);
    setInputValue(toNumber(v));
    onChange(toNumber(v));
  };

  var handleDealError = function handleDealError(v) {
    var err = false;

    if (v === null || v === '') {
      if (required) {
        err = true;
      } else {
        err = false;
      }
    } else if (isValid(v)) {
      onError && onError('', v);
    } else {
      if (onError) {
        onError(getErrorMessage(v), v);
      }

      err = true;
    }

    setError(err);
  };

  var handleStepBackClick = function handleStepBackClick(e) {
    handleStep(-1, e);
  };

  var handleStepForwardClick = function handleStepForwardClick(e) {
    handleStep(1, e);
  };

  var handleChange = function handleChange(e) {
    var val = e.target.value.trim();
    val = toNumber(parser(val));
    handleDealValue(val);
  };

  var handleBlur = function handleBlur() {
    setIsFocused(false);
  };

  var handleFocus = function handleFocus() {
    setIsFocused(true);
  };

  var handleKeyDown = function handleKeyDown(e, arg) {
    if (!isFocused) {
      return;
    }

    if (e.keyCode === 38) {
      handleStep(1, e);
    }

    if (e.keyCode === 40) {
      handleStep(-1, e);
    }

    if (typeof onKeyDown === 'function') {
      onKeyDown(e, arg);
    }
  };

  var isNotCompleteNumber = function isNotCompleteNumber(value) {
    return isNaN(+value) || value === '' || value.toString().endsWith('.');
  };

  var toNumber = function toNumber(value) {
    if (value === null) {
      return null;
    }

    if (isNotCompleteNumber(value)) {
      return value;
    }

    if (typeof value === 'string') {
      return Number(parseFloat(value).toFixed(precision));
    }

    return Number(value.toFixed(precision));
  };

  react_1.useEffect(function () {
    var v;

    if (value !== undefined) {
      v = value;
    } else if (defaultValue !== undefined) {
      v = defaultValue;
    } else {
      v = '';
    }

    setInputValue(toNumber(v));

    if (required && !v) {
      setError(true);
    }

    handleDealError(v);
  }, [value]);
  react_1.useEffect(function () {
    console.warn('【ultraui】InputNum组件不再维护更新，请使用InputNumber组件代替');
  }, []);
  react_1.useEffect(function () {
    if (inputValue !== null) {
      if (!isNaN(inputValue)) {
        var val = toNumber(inputValue) || 0;

        if (val < max && val > min) {
          setIsMaxDisable(false);
          setIsMinDisable(false);
        } else {
          if (val === min && min === max) {
            setIsMinDisable(true);
            setIsMaxDisable(true);
          } else {
            if (val >= max) {
              setIsMinDisable(false);
              setIsMaxDisable(true);
            }

            if (val <= min) {
              setIsMinDisable(true);
              setIsMaxDisable(false);
            }
          }
        }
      } else {
        setIsMaxDisable(false);
        setIsMinDisable(false);
      }
    }
  }, [inputValue]);
  return {
    inputValue: inputValue,
    isMinDisable: isMinDisable,
    isMaxDisable: isMaxDisable,
    handleStepBackClick: handleStepBackClick,
    handleStepForwardClick: handleStepForwardClick,
    error: error,
    handleChange: handleChange,
    handleBlur: handleBlur,
    handleFocus: handleFocus,
    handleKeyDown: handleKeyDown
  };
};