"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInputNumber = void 0;

var react_1 = require("react");

function defaultParser(input) {
  return input.replace(/[^\w\.-]+/g, '');
}

var maxNumber = Number.MAX_SAFE_INTEGER || 9007199254740991;

exports.useInputNumber = function (_a) {
  var defaultValue = _a.defaultValue,
      value = _a.value,
      _b = _a.precision,
      precision = _b === void 0 ? 6 : _b,
      _c = _a.max,
      max = _c === void 0 ? maxNumber : _c,
      _d = _a.min,
      min = _d === void 0 ? -maxNumber : _d,
      _e = _a.parser,
      parser = _e === void 0 ? defaultParser : _e,
      _f = _a.onChange,
      onChange = _f === void 0 ? function () {} : _f,
      _g = _a.required,
      required = _g === void 0 ? false : _g,
      _h = _a.validateOnBlur,
      validateOnBlur = _h === void 0 ? true : _h,
      _j = _a.disabled,
      disabled = _j === void 0 ? false : _j,
      _k = _a.readOnly,
      readOnly = _k === void 0 ? false : _k,
      _l = _a.readonly,
      readonly = _l === void 0 ? false : _l,
      _m = _a.onBlur,
      onBlur = _m === void 0 ? function () {} : _m,
      _o = _a.onKeyDown,
      onKeyDown = _o === void 0 ? function () {} : _o,
      _p = _a.step,
      step = _p === void 0 ? 1 : _p,
      _q = _a.allowEmpty,
      allowEmpty = _q === void 0 ? false : _q,
      rely = _a.rely;

  var _r = react_1.useState(false),
      isMinDisable = _r[0],
      setIsMinDisable = _r[1];

  var _s = react_1.useState(false),
      isMaxDisable = _s[0],
      setIsMaxDisable = _s[1];

  var _t = react_1.useState(null),
      prevInputValue = _t[0],
      setPrevInputValue = _t[1];

  var _u = react_1.useState(''),
      inputValue = _u[0],
      setInputValue = _u[1];

  var _v = react_1.useState(false),
      isFocus = _v[0],
      setIsFocus = _v[1];

  var inputRef = react_1.useRef();

  var handleStepBack = function handleStepBack() {
    var val = +toNumber(inputValue);
    val = val - step;
    handleDealValue(String(Math.min(Math.max(min, val), max)));
  };

  var handleStepForward = function handleStepForward() {
    var val = +toNumber(inputValue);
    val = val + step;
    handleDealValue(String(Math.min(Math.max(min, val), max)));
  };

  var isNotCompleteNumber = function isNotCompleteNumber(val) {
    return isNaN(+val) || val === '' || val.toString().endsWith('.') || val.toString().endsWith('0') && val.toString().includes('.');
  };

  var toNumber = function toNumber(v) {
    if (v === null) {
      return '';
    }

    if (isNotCompleteNumber(v)) {
      return v;
    }

    if (typeof precision === 'number') {
      return +(+v).toFixed(precision);
    }

    return +v;
  };

  var handleDealValue = function handleDealValue(v) {
    var newV = toNumber(v);

    if (inputValue && !isNaN(+inputValue) && inputValue >= min && inputValue <= max) {
      setPrevInputValue(inputValue);
    }

    var fv = newV === '' && !allowEmpty ? defaultValue || value || min : newV;
    setInputValue(fv);
    onChange(fv);
  };

  var handleChange = function handleChange(e) {
    var v = parser(e.target.value.trim());
    var newV = toNumber(v);

    if (inputValue && !isNaN(+inputValue) && inputValue >= min && inputValue <= max) {
      setPrevInputValue(inputValue);
    }

    if (newV >= maxNumber) {
      setInputValue(v); // onChange(v)

      return;
    }

    if (!isNaN(+newV)) {
      setInputValue(newV);
      onChange(newV);
    }
  };

  var getNumberfromString = function getNumberfromString(str) {
    var splitNums = /\d+(\.\d+)?/.exec(str);

    if (splitNums !== null) {
      return +splitNums[0];
    } else {
      return null;
    }
  };

  var handleBlur = function handleBlur(e) {
    var v = +inputValue;

    if (!required && getNumberfromString(inputValue) === null) {
      v = '';
    } else {
      if (!isNotCompleteNumber(inputValue)) {
        if (v < min) {
          v = min;
        }

        if (v > max) {
          v = max;
        }
      } else {
        if (inputValue !== 'NaN') {
          var num = getNumberfromString(inputValue);

          if (num !== null) {
            v = num;

            if (num < min) {
              v = min;
            }

            if (num > max) {
              v = max;
            }
          } else {
            v = NaN;
          }
        }
      }
    }

    if (isNaN(v)) {
      handleDealValue(String(prevInputValue));
    } else {
      handleDealValue(String(v));
    }

    setIsFocus(false);

    if (validateOnBlur) {
      onBlur(e);
    }
  };

  var handleFocus = function handleFocus() {
    setIsFocus(true);
  };

  var handleWheel = function handleWheel(e) {
    e.preventDefault();

    if (disabled || readonly || readOnly) {
      return;
    }

    setIsFocus(true);

    if (e.deltaY > 0) {
      handleStepForward();
    } else {
      handleStepBack();
    }
  };

  var handleKeyDown = function handleKeyDown(e, arg) {
    if (!isFocus) {
      return;
    }

    if (e.keyCode === 38) {
      handleStepForward();
    }

    if (e.keyCode === 40) {
      handleStepBack();
    }

    if (typeof onKeyDown === 'function') {
      onKeyDown(e, arg);
    }
  };

  react_1.useEffect(function () {
    var v;

    if (value !== undefined) {
      v = value;
    } else if (defaultValue !== undefined) {
      v = defaultValue;
    } else {
      v = '';
    }

    setPrevInputValue(toNumber(v));
    setInputValue(toNumber(v));
    onChange(toNumber(v));
  }, [value]);
  react_1.useEffect(function () {
    if (inputValue !== null) {
      if (!isNaN(inputValue)) {
        var val = toNumber(inputValue) || 0;

        if (val < max && val > min) {
          setIsMaxDisable(false);
          setIsMinDisable(false);
        } else {
          if (val === min && min === max) {
            setIsMinDisable(true);
            setIsMaxDisable(true);
          } else {
            if (val >= max) {
              setIsMinDisable(false);
              setIsMaxDisable(true);
            }

            if (val <= min) {
              setIsMinDisable(true);
              setIsMaxDisable(false);
            }
          }
        }
      } else {
        setIsMaxDisable(false);
        setIsMinDisable(false);
      }
    }
  }, [inputValue]);
  react_1.useEffect(function () {
    if (inputRef.current) {
      inputRef.current.addEventListener('wheel', handleWheel, {
        passive: false
      });
    }

    return function () {
      inputRef.current.removeEventListener('wheel', handleWheel, {
        passive: false
      });
    };
  }, [inputValue, disabled, readonly, readOnly, rely]);
  return {
    isMinDisable: isMinDisable,
    isMaxDisable: isMaxDisable,
    handleStepBack: handleStepBack,
    handleStepForward: handleStepForward,
    inputValue: inputValue,
    handleChange: handleChange,
    handleBlur: handleBlur,
    handleFocus: handleFocus,
    inputRef: inputRef,
    handleKeyDown: handleKeyDown
  };
};