"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInputNumbers = void 0;

var react_1 = require("react");

var number_1 = require("../../utils/tools/number");

var BTN_TYPE;

(function (BTN_TYPE) {
  BTN_TYPE[BTN_TYPE["UP"] = 1] = "UP";
  BTN_TYPE[BTN_TYPE["DOWN"] = -1] = "DOWN";
})(BTN_TYPE || (BTN_TYPE = {}));

var maxNumber = Number.MAX_SAFE_INTEGER || 9007199254740991;

exports.useInputNumbers = function (_a) {
  var min = _a.min,
      max = _a.max,
      _b = _a.precision,
      precision = _b === void 0 ? 2 : _b,
      value = _a.value,
      defaultValue = _a.defaultValue,
      _c = _a.onChange,
      onChange = _c === void 0 ? function () {} : _c,
      _d = _a.step,
      step = _d === void 0 ? 1 : _d;

  var _e = react_1.useState(false),
      upDisable = _e[0],
      setUpDisable = _e[1];

  var _f = react_1.useState(false),
      downDisable = _f[0],
      setDownDisable = _f[1];

  var _g = react_1.useState(false),
      sameDisable = _g[0],
      setSameDisable = _g[1];

  var _h = react_1.useState(''),
      inputValue = _h[0],
      setInputValue = _h[1];

  var _j = react_1.useState(''),
      prevInputValue = _j[0],
      setPrevInputValue = _j[1];

  var handleStep = function handleStep(type) {
    var v = inputValue + step * type;
    var pre = prevInputValue;
    var val = inputValue;
    var downDis = false;
    var upDis = false;

    if (number_1.isNumber(inputValue)) {
      if (min !== undefined && v <= -maxNumber && type === BTN_TYPE.DOWN) {
        pre = val = toNumber(min);
        downDis = true;
        upDis = false;
      } else if (max !== undefined && v >= maxNumber && type === BTN_TYPE.UP) {
        pre = val = toNumber(max);
        downDis = false;
        upDis = true;
      } else {
        pre = val = toNumber(v);
      }
    } else {
      // 空字符串或者其他不是数字的
      pre = val = toNumber(min !== undefined ? min : 0);
    }

    setPrevInputValue(pre);
    setInputValue(val);
    setUpDisable(upDis);
    setDownDisable(downDis);

    if (typeof onChange === 'function') {
      onChange(val);
    }
  };

  var handleStepBack = function handleStepBack() {
    handleStep(BTN_TYPE.DOWN);
  };

  var handleStepForward = function handleStepForward() {
    handleStep(BTN_TYPE.UP);
  };

  var handleChange = function handleChange(e) {
    var v = e.target.value;
    handleSetPreValue(v);

    if (typeof onChange === 'function') {
      onChange(v);
    }
  };

  var handleBlur = function handleBlur() {
    var pre;
    var val;
    var downDis = false;
    var upDis = false;

    if (inputValue && number_1.isNumber(inputValue)) {
      if (min !== undefined && inputValue <= min) {
        pre = val = toNumber(min);
        downDis = true;
        upDis = false;
      } else if (max !== undefined && inputValue >= max) {
        pre = val = toNumber(max);
        downDis = false;
        upDis = true;
      } else {
        pre = val = toNumber(inputValue);
      }
    } else if (inputValue === '') {
      pre = val = inputValue;
    } else {
      pre = val = prevInputValue;
    }

    setPrevInputValue(pre);
    setInputValue(val);
    setUpDisable(upDis);
    setDownDisable(downDis);

    if (typeof onChange === 'function') {
      onChange(val);
    }
  };

  var toNumber = function toNumber(val) {
    return parseFloat(parseFloat(val).toFixed(precision));
  };

  var handleSetPreValue = function handleSetPreValue(v) {
    if (number_1.isNumber(v)) {
      setPrevInputValue(v);
      setInputValue(v);
    } else {
      setInputValue(v);
    }
  };

  react_1.useEffect(function () {
    var v;

    if (value !== undefined) {
      v = value;
    } else if (defaultValue !== undefined) {
      v = defaultValue;
    } else {
      v = '';
    }

    handleSetPreValue(v);
  }, [value]);
  react_1.useEffect(function () {
    console.warn('【ultraui】InputNumers组件不再维护更新，请使用InputNumber组件代替');
  }, []);
  react_1.useEffect(function () {
    if (inputValue && +inputValue === max && max === min) {
      setSameDisable(true);
    }
  }, [inputValue]);
  return {
    inputValue: inputValue,
    upDisable: upDisable,
    downDisable: downDisable,
    sameDisable: sameDisable,
    handleStepBack: handleStepBack,
    handleStepForward: handleStepForward,
    handleChange: handleChange,
    handleBlur: handleBlur
  };
};