"use strict";

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});

var react_1 = __importDefault(require("react"));

var classnames_1 = __importDefault(require("classnames"));

var StepHead_1 = __importDefault(require("./StepHead"));

var StepBody_1 = __importDefault(require("./StepBody"));

var StepFoot_1 = __importDefault(require("./StepFoot"));

var StepPanel_1 = __importDefault(require("./StepPanel"));

var useStep_1 = __importDefault(require("./useStep"));

var locale = window.LangCode || 'en';
var i18nMap = {
  en: {
    previous: 'Previous',
    next: 'Next',
    finish: 'Finish'
  },
  'zh_CN': {
    previous: '上一步',
    next: '下一步',
    finish: '完成'
  }
};
/**
 * Step 组件展示
 * @param props
 */

var Step = function Step(props) {
  var _a = useStep_1["default"](props),
      currentActiveIndex = _a.currentActiveIndex,
      total = _a.total,
      handleFinish = _a.handleFinish,
      handlePrevStep = _a.handlePrevStep,
      handleNextStep = _a.handleNextStep,
      handleOnActive = _a.handleOnActive;

  var _b = props.prefixCls,
      prefixCls = _b === void 0 ? 'ult' : _b,
      children = props.children,
      _c = props.showProgress,
      showProgress = _c === void 0 ? false : _c,
      _d = props.tabMode,
      tabMode = _d === void 0 ? false : _d,
      _e = props.bodyStyle,
      bodyStyle = _e === void 0 ? {} : _e,
      _f = props.previous,
      previous = _f === void 0 ? i18nMap[locale].previous : _f,
      _g = props.next,
      next = _g === void 0 ? i18nMap[locale].next : _g,
      _h = props.finish,
      finish = _h === void 0 ? i18nMap[locale].finish : _h,
      _j = props.btndisable,
      btndisable = _j === void 0 ? false : _j,
      _k = props.nofinish,
      nofinish = _k === void 0 ? false : _k,
      _l = props.noFoot,
      noFoot = _l === void 0 ? false : _l,
      _m = props.className,
      className = _m === void 0 ? '' : _m,
      _o = props.style,
      style = _o === void 0 ? {} : _o;

  function renderStepHead() {
    return react_1["default"].createElement(StepHead_1["default"], {
      key: "stepHead",
      prefixCls: prefixCls,
      panels: children,
      activeIndex: currentActiveIndex,
      showProgress: showProgress,
      onActive: handleOnActive,
      tabMode: tabMode
    });
  }

  function renderStepBody() {
    return react_1["default"].createElement(StepBody_1["default"], {
      key: "stepBody",
      prefixCls: prefixCls,
      style: bodyStyle,
      activeIndex: currentActiveIndex,
      panels: children
    });
  }

  function renderStepFoot() {
    return !noFoot ? react_1["default"].createElement(StepFoot_1["default"], {
      key: "stepFoot",
      prefixCls: prefixCls,
      previous: previous,
      next: next,
      finish: finish,
      btndisable: btndisable,
      activeIndex: currentActiveIndex,
      complete: currentActiveIndex === total - 1,
      onNextStep: handleNextStep,
      onPrevStep: handlePrevStep,
      onFinish: handleFinish,
      nofinish: nofinish
    }) : null;
  }

  var classes = classnames_1["default"](prefixCls + "-step", {}, className);
  return react_1["default"].createElement("div", {
    className: classes,
    style: style
  }, renderStepHead(), renderStepBody(), renderStepFoot());
};

Step.StepPanel = StepPanel_1["default"];
exports["default"] = Step;