"use strict";

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCheckAllTable = void 0;

var react_1 = require("react");

var hooks_1 = require("../../../hooks");

var lodash_1 = __importDefault(require("lodash"));

exports.useCheckAllTable = function (_a, ref) {
  var _b = _a.checkData,
      checkData = _b === void 0 ? [] : _b,
      columns = _a.columns,
      data = _a.data,
      onCheckedAll = _a.onCheckedAll,
      rowClassName = _a.rowClassName,
      onChecked = _a.onChecked,
      _c = _a.shouldClear,
      shouldClear = _c === void 0 ? true : _c;

  var _d = react_1.useState(null),
      prevData = _d[0],
      setPrevData = _d[1];

  var _e = react_1.useState(null),
      prevColumns = _e[0],
      setPrevColumns = _e[1];

  var _f = react_1.useState(function () {
    var checkedNumber = checkData.filter(function (item) {
      return !!item;
    }).length;
    var dataRealCheckedNumber = data.filter(function (item) {
      return !item.checkDisabled;
    }).length;
    return checkedNumber === dataRealCheckedNumber && dataRealCheckedNumber !== 0;
  }),
      isAllChecked = _f[0],
      setIsAllChecked = _f[1];

  var _g = hooks_1.useStateCallback(function () {
    if (checkData && checkData.length > 0) {
      return checkData;
    } else {
      return data.map(function () {
        return false;
      });
    }
  }),
      rowState = _g[0],
      setRowState = _g[1];

  react_1.useImperativeHandle(ref, function () {
    return {
      getSelected: getSelected,
      reset: reset
    };
  }, [data, rowState]);

  var _h = react_1.useState(function () {
    return data.filter(function (item) {
      return !item.checkDisabled;
    }).length;
  }),
      allowCheckCount = _h[0],
      setAllowCheckCount = _h[1];

  var handleCheckOne = function handleCheckOne(row, data, checked) {
    var _rowState = lodash_1["default"].cloneDeep(rowState);

    _rowState[row] = checked;
    setRowState(function () {
      return _rowState;
    }, function () {
      if (typeof onChecked === 'function') {
        onChecked(checked ? data : null);
      }
    });
    setIsAllChecked(function () {
      return allowCheckCount > 0 && _rowState.filter(function (item) {
        return item === true;
      }).length === allowCheckCount;
    });
  };

  var handleCheckAll = function handleCheckAll() {
    var currentAllChecked = !isAllChecked;
    setRowState(function () {
      return data.map(function (item) {
        if (item.hidden || item.checkDisabled) {
          return false;
        } else {
          return currentAllChecked;
        }
      });
    }, function () {
      if (onCheckedAll && typeof onCheckedAll === 'function') {
        onCheckedAll(currentAllChecked ? data.filter(function (item) {
          return !(item.hidden || item.checkDisabled);
        }) : []);
      }
    });
    setIsAllChecked(currentAllChecked);
  };

  var getSelected = function getSelected() {
    return rowState.map(function (checked, index) {
      if (checked) {
        return data[index];
      } else {
        return false;
      }
    }).filter(function (item) {
      return item !== false;
    });
  };

  var genRowClass = function genRowClass(record, index, indent) {
    var cls = '';

    if (record.hidden) {
      cls = 'neo-multitable-hidden';
    }

    if (typeof rowClassName === 'function') {
      cls += ' ' + rowClassName(record, index, indent);
    }

    return cls;
  };

  var reset = function reset() {
    setRowState(data.map(function (_) {
      return false;
    }));
    setIsAllChecked(false);
  };

  react_1.useEffect(function () {
    if (checkData && checkData.length > 0) {
      setRowState(checkData);
    } else {
      setRowState(data.map(function () {
        return false;
      }));
    }
  }, []);

  var initData = function initData() {
    if (shouldClear) {
      reset();
      setAllowCheckCount(data.filter(function (item) {
        return !item.checkDisabled;
      }).length);
    } else {
      if (checkData && checkData.length > 0) {
        setIsAllChecked(checkData.filter(function (item) {
          return !!item;
        }).length === data.filter(function (item) {
          return !item.checkDisabled;
        }).length && data.filter(function (item) {
          return !item.checkDisabled;
        }).length !== 0);
        setRowState(checkData);
        setAllowCheckCount(data.filter(function (item) {
          return !item.checkDisabled;
        }).length);
      } else {
        setAllowCheckCount(data.filter(function (item) {
          return !item.checkDisabled;
        }).length);
      }
    }

    if (lodash_1["default"].isEmpty(data) && isAllChecked && shouldClear) {
      reset();
    }
  };

  var isDifferent = function isDifferent(prevData, data) {
    if (prevData === data) {
      return false;
    } else {
      return !lodash_1["default"].isEqual(prevData, data);
    }
  };

  if (isDifferent(prevData, data)) {
    initData();
    setPrevData(data);
  }

  if (prevColumns !== columns) {
    setAllowCheckCount(data.filter(function (item) {
      return !item.checkDisabled;
    }).length);
    setPrevColumns(columns);
  }

  return {
    isAllChecked: isAllChecked,
    handleCheckAll: handleCheckAll,
    genRowClass: genRowClass,
    rowState: rowState,
    handleCheckOne: handleCheckOne
  };
};