"use strict";

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTooltipAlign = exports.useTooltip = void 0;

var react_1 = require("react");

var react_dom_1 = __importDefault(require("react-dom"));

var lodash_1 = require("lodash");

var dom_align_1 = __importDefault(require("dom-align"));

var classnames_1 = __importDefault(require("classnames"));

var uuid_1 = __importDefault(require("uuid"));

exports.useTooltip = function (_a) {
  var _b = _a.trigger,
      trigger = _b === void 0 ? 'hover' : _b;

  var _c = react_1.useState(false),
      show = _c[0],
      setShow = _c[1];

  var handleToggle = function handleToggle(e) {
    e.preventDefault();
    e.nativeEvent.stopImmediatePropagation();
    setShow(!show);
  };

  var handleClickToggle = function handleClickToggle(e) {
    if (trigger === 'click') {
      handleToggle(e);
    }
  };

  var handleMouseEnter = function handleMouseEnter() {
    if (trigger === 'hover') {
      setShow(true);
    }
  };

  var handleMouseLeave = function handleMouseLeave() {
    if (trigger === 'hover') {
      setShow(false);
    }
  };

  var handleCollapse = function handleCollapse() {
    setShow(false);
  };

  react_1.useEffect(function () {
    document.addEventListener('click', handleCollapse);
    return function () {
      document.removeEventListener('click', handleCollapse);
    };
  }, []);
  return {
    show: show,
    handleClickToggle: handleClickToggle,
    handleMouseEnter: handleMouseEnter,
    handleMouseLeave: handleMouseLeave
  };
};

exports.useTooltipAlign = function (_a, tipContent, tipEmpty) {
  var _b;

  var _c = _a.trigger,
      trigger = _c === void 0 ? 'hover' : _c,
      _d = _a.prefixCls,
      prefixCls = _d === void 0 ? 'ult' : _d,
      _e = _a.placement,
      placement = _e === void 0 ? 'top' : _e,
      _f = _a.className,
      className = _f === void 0 ? '' : _f,
      _g = _a.scrollContainer,
      scrollContainer = _g === void 0 ? null : _g,
      visible = _a.visible;
  var wrapperId = 'wrap-tooltip-align-' + uuid_1["default"].v4();

  var _h = react_1.useState(false),
      show = _h[0],
      setShow = _h[1];

  var rooRef = react_1.useRef();
  var classes = classnames_1["default"]((_b = {}, _b[prefixCls + "-tooltip-align"] = true, _b[prefixCls + "-tooltip-" + placement] = !!placement, _b), className);

  var handleClickToggle = function handleClickToggle(e) {
    if (trigger === 'click') {
      e.preventDefault();
      e.nativeEvent.stopImmediatePropagation();
      setShow(!show);
    }
  };

  var handleMouseEnter = function handleMouseEnter() {
    trigger === 'hover' && setShow(true);
  };

  var handleMouseLeave = function handleMouseLeave() {
    trigger === 'hover' && setShow(false);
  };

  var handleCollapse = function handleCollapse() {
    setShow(false);
  };

  var handleInitWrapper = function handleInitWrapper() {
    handleClearWrapper();
    var wrapper = document.createElement('div');
    wrapper.id = wrapperId;
    wrapper.style.position = 'absolute';
    wrapper.style.left = '0';
    wrapper.style.top = '0';
    var container = document.querySelector(scrollContainer) || document.body;
    container.appendChild(wrapper);
    return wrapper;
  };

  var handleClearWrapper = function handleClearWrapper() {
    var wp = document.getElementById(wrapperId);

    if (wp) {
      react_dom_1["default"].unmountComponentAtNode(wp);

      if (typeof wp.remove === 'function') {
        wp.remove();
      }
    }
  };

  var wdiv = document.createElement('div');
  var tipModal = react_1.useRef(wdiv);

  var handleInitTipModal = function handleInitTipModal(wrapper) {
    tipModal.current.className = classes;
    wrapper.appendChild(tipModal.current);
  };

  var handlePosition = function handlePosition() {
    if (!tipModal.current || !rooRef.current) {
      return;
    }

    var place = {
      bottom: ['tc', 'bc'],
      bottomLeft: ['tl', 'bl'],
      bottomRight: ['tr', 'br'],
      top: ['bc', 'tc'],
      topLeft: ['bl', 'tl'],
      topRight: ['br', 'tr'],
      left: ['cr', 'cl'],
      leftTop: ['tr', 'tl'],
      leftBottom: ['br', 'bl'],
      right: ['cl', 'cr'],
      rightTop: ['tl', 'tr'],
      rightBottom: ['bl', 'br']
    };
    var offsets = {
      bottom: [0, 0],
      bottomLeft: [0, 0],
      bottomRight: [0, 0],
      top: [0, 0],
      topLeft: [0, 0],
      topRight: [0, 0],
      left: [-4, 0],
      leftTop: [-4, 0],
      leftBottom: [-4, 0],
      right: [4, 0],
      rightTop: [4, 0],
      rightBottom: [4, 0]
    };
    dom_align_1["default"](tipModal.current, rooRef.current, {
      points: place[placement],
      offset: offsets[placement],
      targetOffset: [0, 0],
      overflow: {
        adjustX: true,
        adjustY: true,
        alwaysByViewport: true
      }
    });
  };

  var _throttle;

  react_1.useEffect(function () {
    handleInitTipModal(handleInitWrapper());

    if (scrollContainer && document.querySelector(scrollContainer)) {
      _throttle = lodash_1.throttle(handlePosition, 500, {
        leading: false,
        trailing: true
      });
      document.querySelector(scrollContainer).addEventListener('scroll', _throttle);
    } // 处理在Dialog等组件中使用，作为自组件获取不到正确位置的情况


    setTimeout(function () {
      handlePosition();
    }, 300);
    document.addEventListener('click', handleCollapse);
    return function () {
      handleClearWrapper();

      if (scrollContainer && document.querySelector(scrollContainer)) {
        document.querySelector(scrollContainer).removeEventListener('scroll', _throttle);
      }

      document.removeEventListener('click', handleCollapse);
    };
  }, []);
  react_1.useEffect(function () {
    var isShow = visible === null ? show : visible;

    if (isShow) {
      react_dom_1["default"].render(tipContent, tipModal.current);
      handlePosition();
    } else {
      react_dom_1["default"].render(tipEmpty, tipModal.current);
    }
  }, [show, visible]);
  return {
    rooRef: rooRef,
    handleClickToggle: handleClickToggle,
    handleMouseEnter: handleMouseEnter,
    handleMouseLeave: handleMouseLeave
  };
};