"use strict";

var __spreadArrays = void 0 && (void 0).__spreadArrays || function () {
  for (var s = 0, i = 0, il = arguments.length; i < il; i++) {
    s += arguments[i].length;
  }

  for (var r = Array(s), k = 0, i = 0; i < il; i++) {
    for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) {
      r[k] = a[j];
    }
  }

  return r;
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTransferList = exports.useTransfer = void 0;

var react_1 = require("react");

exports.useTransfer = function (_a) {
  var _b = _a.dataSource,
      dataSource = _b === void 0 ? [] : _b,
      targetKeys = _a.targetKeys,
      selectedKeys = _a.selectedKeys,
      _c = _a.onChange,
      onChange = _c === void 0 ? function () {} : _c,
      _d = _a.onSelectChange,
      onSelectChange = _d === void 0 ? function () {} : _d,
      rowKey = _a.rowKey,
      _e = _a.onSearch,
      onSearch = _e === void 0 ? function () {} : _e;

  var _f = react_1.useState([]),
      leftDataSource = _f[0],
      setLeftDataSource = _f[1];

  var _g = react_1.useState([]),
      rightDataSource = _g[0],
      setRightDataSource = _g[1];

  var _h = react_1.useState(''),
      leftFilter = _h[0],
      setLeftFilter = _h[1];

  var _j = react_1.useState(''),
      rightFilter = _j[0],
      setRightFilter = _j[1];

  var _k = react_1.useState([]),
      sourceSelectedKeys = _k[0],
      setSourceSelectedKeys = _k[1];

  var _l = react_1.useState([]),
      targetSelectedKeys = _l[0],
      setTargetSelectedKeys = _l[1];

  react_1.useEffect(function () {
    var _selectedKeys = selectedKeys || [];

    var _targetKeys = targetKeys || [];

    setSourceSelectedKeys(_selectedKeys.filter(function (key) {
      return !_targetKeys.includes(key);
    }));
    setTargetSelectedKeys(_selectedKeys.filter(function (key) {
      return _targetKeys.includes(key);
    }));
  }, [selectedKeys, targetKeys]);
  react_1.useEffect(function () {
    var _targetKeys = targetKeys || [];

    var _leftDataSource = [];

    var _rightDataSource = new Array(_targetKeys.length);

    dataSource.forEach(function (record) {
      if (rowKey) {
        record.key = rowKey(record);
      }

      var keyIndex = _targetKeys.indexOf(record.key);

      if (keyIndex !== -1) {
        _rightDataSource[keyIndex] = record;
      } else {
        _leftDataSource.push(record);
      }
    });
    setLeftDataSource(_leftDataSource);
    setRightDataSource(_rightDataSource);
  }, [dataSource, targetKeys]);

  var handleLeftFilter = function handleLeftFilter(v) {
    return handleFilter('left', v);
  };

  var handleRightFilter = function handleRightFilter(v) {
    return handleFilter('right', v);
  };

  var handleFilter = function handleFilter(direction, v) {
    var val = v;

    if (direction === 'left') {
      setLeftFilter(val);
    }

    if (direction === 'right') {
      setRightFilter(val);
    }

    if (typeof onSearch === 'function') {
      onSearch(direction, val);
    }
  };

  var handleLeftSelect = function handleLeftSelect(selectedItem, checked) {
    handleSelect('left', selectedItem, checked);
  };

  var handleRightSelect = function handleRightSelect(selectedItem, checked) {
    handleSelect('right', selectedItem, checked);
  };

  var handleSelect = function handleSelect(direction, selectedItem, checked) {
    var holder = direction === 'left' ? sourceSelectedKeys : targetSelectedKeys;
    var selectedIndex = holder.indexOf(selectedItem.key);

    if (selectedIndex > -1) {
      holder.splice(selectedIndex, 1);
    }

    if (checked) {
      holder.push(selectedItem.key);
    }

    handleSelectChange(direction, holder);
  };

  var handleLeftSelectAll = function handleLeftSelectAll(filteredDataSource, checkAll) {
    handleSelectAll('left', filteredDataSource, checkAll);
  };

  var handleRightSelectAll = function handleRightSelectAll(filteredDataSource, checkAll) {
    handleSelectAll('right', filteredDataSource, checkAll);
  };

  var handleSelectAll = function handleSelectAll(direction, filteredDataSource, checkAll) {
    var originSelectedKey = direction === 'left' ? sourceSelectedKeys : targetSelectedKeys;
    var currentKeys = filteredDataSource.map(function (record) {
      return record.key;
    });
    var newKeys1 = originSelectedKey.filter(function (key) {
      return !currentKeys.includes(key);
    });

    var newKeys2 = __spreadArrays(originSelectedKey);

    currentKeys.forEach(function (key) {
      if (!newKeys2.includes(key)) {
        newKeys2.push(key);
      }
    });
    var holder = checkAll ? newKeys1 : newKeys2;
    handleSelectChange(direction, holder);
  };

  var handleSelectChange = function handleSelectChange(direction, holder) {
    if (typeof onSelectChange === 'function') {
      if (direction === 'left') {
        onSelectChange(holder, targetSelectedKeys);
      } else {
        onSelectChange(sourceSelectedKeys, holder);
      }
    }

    if (!selectedKeys) {
      if (direction === 'left') {
        setSourceSelectedKeys(holder);
      } else {
        setTargetSelectedKeys(holder);
      }
    }
  };

  var moveToRight = function moveToRight() {
    moveTo('right');
  };

  var moveToLeft = function moveToLeft() {
    moveTo('left');
  };

  var moveTo = function moveTo(direction) {
    var _targetKeys = targetKeys || [];

    var moveKeys = direction === 'right' ? sourceSelectedKeys : targetSelectedKeys;
    var newMoveKeys = moveKeys.filter(function (key) {
      return !dataSource.some(function (item) {
        return item.key === key && item.disabled;
      });
    });
    var newTargetKeys = direction === 'right' ? newMoveKeys.concat(_targetKeys) : _targetKeys.filter(function (targetKey) {
      return !newMoveKeys.includes(targetKey);
    });

    if (direction === 'right') {
      setSourceSelectedKeys([]);
      handleSelectChange('left', []);
    } else {
      setTargetSelectedKeys([]);
      handleSelectChange('right', []);
    }

    if (onChange) {
      onChange(newTargetKeys, direction, newMoveKeys);
    }
  };

  return {
    leftDataSource: leftDataSource,
    rightDataSource: rightDataSource,
    sourceSelectedKeys: sourceSelectedKeys,
    targetSelectedKeys: targetSelectedKeys,
    leftFilter: leftFilter,
    rightFilter: rightFilter,
    handleLeftFilter: handleLeftFilter,
    handleRightFilter: handleRightFilter,
    handleLeftSelect: handleLeftSelect,
    handleRightSelect: handleRightSelect,
    handleLeftSelectAll: handleLeftSelectAll,
    handleRightSelectAll: handleRightSelectAll,
    moveToRight: moveToRight,
    moveToLeft: moveToLeft
  };
};

exports.useTransferList = function (_a) {
  var _b = _a.dataSource,
      dataSource = _b === void 0 ? [] : _b,
      _c = _a.render,
      render = _c === void 0 ? function () {} : _c,
      filterOption = _a.filterOption,
      _d = _a.filter,
      filter = _d === void 0 ? '' : _d,
      _e = _a.checkedKeys,
      checkedKeys = _e === void 0 ? [] : _e,
      _f = _a.handleSelect,
      handleSelect = _f === void 0 ? function () {} : _f;

  var _g = react_1.useState([]),
      filteredDataSource = _g[0],
      setFilteredDataSource = _g[1]; // filter字段过滤且非disabled的数据


  var _h = react_1.useState([]),
      totalDataSource = _h[0],
      setTotalDataSource = _h[1]; // filter字段过滤的数据


  var _j = react_1.useState(false),
      checkedAll = _j[0],
      setCheckedAll = _j[1];

  var matchFilter = function matchFilter(item) {
    var text = render(item);

    if (filterOption) {
      return filterOption(filter, item);
    }

    return text.includes(filter);
  };

  var handleSelectItem = function handleSelectItem(selectedItem) {
    var result = checkedKeys.some(function (key) {
      return key === selectedItem.key;
    });
    handleSelect(selectedItem, !result);
  };

  react_1.useEffect(function () {
    var _filteredDataSource = [];
    var _totalDataSource = [];
    dataSource.forEach(function (item) {
      if (filter && filter.trim() && !matchFilter(item)) {
        return;
      }

      _totalDataSource.push(item);

      if (!item.disabled) {
        _filteredDataSource.push(item);
      }
    });
    setFilteredDataSource(_filteredDataSource);
    setTotalDataSource(_totalDataSource);
  }, [dataSource, filter]);
  react_1.useEffect(function () {
    setCheckedAll(filteredDataSource.every(function (item) {
      return checkedKeys.includes(item.key);
    }));
  }, [filteredDataSource, checkedKeys]);
  return {
    checkedAll: checkedAll,
    filteredDataSource: filteredDataSource,
    totalDataSource: totalDataSource,
    handleSelectItem: handleSelectItem
  };
};