"use strict";

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
/* eslint react/prop-types: 0 */

/*
 * @Author: SiMeiyu
 * @Date: 2017-07-04 10:08:34
 */

var react_1 = __importDefault(require("react"));

var classnames_1 = __importDefault(require("classnames"));

var Icon_1 = __importDefault(require("../Icon"));

require("./tree.less");

var renderLine = function renderLine(props) {
  var _a;

  var _b = props.prefixCls,
      prefixCls = _b === void 0 ? 'ult' : _b,
      _c = props.showLine,
      showLine = _c === void 0 ? false : _c;
  var classes = classnames_1["default"]((_a = {}, _a[prefixCls + "-tree-node-line"] = true, _a));

  if (!showLine) {
    return null;
  }

  return react_1["default"].createElement("span", {
    className: classes
  });
};

var renderSwitch = function renderSwitch(props) {
  var _a;

  var _b = props.prefixCls,
      prefixCls = _b === void 0 ? 'ult' : _b,
      _c = props.switchIcon,
      switchIcon = _c === void 0 ? [] : _c,
      _d = props.isParent,
      isParent = _d === void 0 ? false : _d,
      _e = props.open,
      open = _e === void 0 ? true : _e;
  var classes = classnames_1["default"]('iconfont', (_a = {}, _a["icon-" + switchIcon[0]] = !open, _a["icon-" + switchIcon[1]] = open, _a[prefixCls + "-tree-node-switch"] = true, _a));

  if (!isParent) {
    return null;
  }

  return react_1["default"].createElement("span", {
    className: classes,
    onClick: function onClick(e) {
      return handleSwitch(e, props);
    }
  });
};

var renderMultiple = function renderMultiple(props) {
  var _a;

  var _b = props.prefixCls,
      prefixCls = _b === void 0 ? 'ult' : _b,
      _c = props.multiple,
      multiple = _c === void 0 ? false : _c,
      checked = props.checked;
  var classes = classnames_1["default"]((_a = {}, _a[prefixCls + "-tree-node-checkbox"] = true, _a[prefixCls + "-tree-node-checkbox-checked"] = checked, _a));

  if (!multiple) {
    return null;
  }

  return react_1["default"].createElement("span", {
    className: classes,
    onClick: function onClick(e) {
      return handleChecked(e, props);
    }
  });
};

var renderIcon = function renderIcon(props) {
  var _a;

  var _b = props.prefixCls,
      prefixCls = _b === void 0 ? 'ult' : _b,
      _c = props.open,
      open = _c === void 0 ? true : _c,
      _d = props.icon,
      icon = _d === void 0 ? '' : _d,
      _e = props.iconOpen,
      iconOpen = _e === void 0 ? '' : _e,
      _f = props.iconClose,
      iconClose = _f === void 0 ? '' : _f,
      _g = props.isParent,
      isParent = _g === void 0 ? false : _g,
      _h = props.showIcon,
      showIcon = _h === void 0 ? false : _h;
  var nodeIcon = isParent ? open ? iconOpen : iconClose : icon;
  var classes = classnames_1["default"]('iconfont', (_a = {}, _a["icon-" + nodeIcon] = true, _a[prefixCls + "-tree-node-icon"] = true, _a));

  if (!showIcon) {
    return null;
  }

  return react_1["default"].createElement("span", {
    className: classes
  });
};

var renderChildren = function renderChildren(props) {
  var _a;

  var _b = props.prefixCls,
      prefixCls = _b === void 0 ? 'ult' : _b,
      _c = props.showLine,
      showLine = _c === void 0 ? false : _c,
      children = props.children,
      _d = props.open,
      open = _d === void 0 ? true : _d,
      _e = props.showIcon,
      showIcon = _e === void 0 ? false : _e,
      _f = props.multiple,
      multiple = _f === void 0 ? false : _f,
      selectable = props.selectable,
      _g = props.switchIcon,
      switchIcon = _g === void 0 ? [] : _g,
      _h = props.selectedKey,
      selectedKey = _h === void 0 ? '' : _h,
      _j = props.checkedKeys,
      checkedKeys = _j === void 0 ? [] : _j;
  var classes = classnames_1["default"](prefixCls + "-tree", (_a = {}, _a[prefixCls + "-tree-line"] = showLine, _a));

  if (!children || !open) {
    return null;
  }

  return react_1["default"].createElement("ul", {
    className: classes
  }, react_1["default"].Children.map(children, function (item) {
    var cloneProps = {
      eventKey: item.key,
      prefixCls: prefixCls,
      showLine: showLine,
      showIcon: showIcon,
      multiple: multiple,
      selectable: selectable,
      switchIcon: switchIcon,
      selected: selectedKey === item.key,
      checked: checkedKeys.find(function (k) {
        return k === item.key;
      })
    };
    return react_1["default"].cloneElement(item, cloneProps);
  }));
};

var handleSwitch = function handleSwitch(e, props) {
  e.stopPropagation();
  props.onSwitch(props.eventKey, !props.open);
};

var handleChecked = function handleChecked(e, props) {
  e.stopPropagation(); // 阻止事件冒泡 选中checkbox，会触发selected事件

  e.preventDefault();

  if (props.disabled) {
    return;
  }

  props.onChecked(e);
};

var handleSelected = function handleSelected(e, props) {
  e.preventDefault();

  if (props.disabled) {
    return;
  }

  props.onSelected(e);
};

var handleDelete = function handleDelete(e, props) {
  e.stopPropagation(); // 阻止事件冒泡 选中checkbox，会触发selected事件

  e.preventDefault();

  if (props.disabled) {
    return;
  }

  props.onDelete(e);
};

var TreeNode = function TreeNode(props) {
  var _a, _b;

  var _c = props.title,
      title = _c === void 0 ? '' : _c,
      _d = props.url,
      url = _d === void 0 ? '' : _d,
      _e = props.isParent,
      isParent = _e === void 0 ? false : _e,
      _f = props.prefixCls,
      prefixCls = _f === void 0 ? 'ult' : _f,
      _g = props.selected,
      selected = _g === void 0 ? false : _g,
      _h = props.disabled,
      disabled = _h === void 0 ? false : _h,
      _j = props.depth,
      depth = _j === void 0 ? 0 : _j,
      ref = props.ref,
      key = props.key,
      isDelete = props.isDelete,
      matchSearch = props.matchSearch;
  return react_1["default"].createElement("li", {
    key: key,
    ref: ref,
    className: classnames_1["default"](prefixCls + "-tree-node", (_a = {}, _a[prefixCls + "-tree-node-parent"] = isParent, _a[prefixCls + "-tree-node-leaf"] = !isParent, _a[prefixCls + "-tree-node-disabled"] = disabled, _a))
  }, react_1["default"].createElement("a", {
    className: classnames_1["default"](prefixCls + "-tree-node-title level-" + depth, (_b = {}, _b[prefixCls + "-tree-node-title-selected"] = selected, _b)),
    href: url,
    onClick: function onClick(e) {
      return handleSelected(e, props);
    }
  }, renderLine(props), renderSwitch(props), renderMultiple(props), renderIcon(props), react_1["default"].createElement("span", {
    className: classnames_1["default"](prefixCls + "-tree-node-name", {
      'match-search': matchSearch
    })
  }, title), isDelete && !disabled && react_1["default"].createElement(Icon_1["default"], {
    type: 'error-o',
    className: prefixCls + "-tree-node-title-delete",
    onClick: function onClick(e) {
      return handleDelete(e, props);
    }
  })), renderChildren(props));
};

exports["default"] = TreeNode;