"use strict";

var __assign = void 0 && (void 0).__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
      }
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

var __spreadArrays = void 0 && (void 0).__spreadArrays || function () {
  for (var s = 0, i = 0, il = arguments.length; i < il; i++) {
    s += arguments[i].length;
  }

  for (var r = Array(s), k = 0, i = 0; i < il; i++) {
    for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) {
      r[k] = a[j];
    }
  }

  return r;
};

Object.defineProperty(exports, "__esModule", {
  value: true
});

var react_1 = require("react");

var getInitiSelectedItem = function getInitiSelectedItem(data, selectedId) {
  var selectedItem = {};

  var loop = function loop(data) {
    data.forEach(function (item) {
      if (item.id === selectedId) {
        selectedItem = item;

        if (item.children) {
          loop(item.children);
        }
      } else if (item.children) {
        loop(item.children);
      }
    });
  };

  loop(data);
  return selectedItem;
};

var getInitiCheckedKeys = function getInitiCheckedKeys(data, checkedIds) {
  var checkedKeys = [];

  var loop = function loop(data) {
    data.forEach(function (item) {
      if (item.checked || checkedIds.includes(item.id)) {
        checkedKeys.push(item.key);

        if (item.children) {
          loop(item.children);
        }
      } else if (item.children) {
        loop(item.children);
      }
    });
  };

  loop(data);
  return checkedKeys;
};

var addExpandedKeys = function addExpandedKeys(data, selected) {
  var loop = function loop(childs, level, parentDisabled) {
    var expandedate = childs.map(function (d, i) {
      var key = level + "-" + i;
      var isParent = !!d.children;
      var disabled = parentDisabled || !!d.disabled;

      if (d.id === selected) {
        setDefaultExpandedNode(d);
      }

      if (!isParent) {
        return __assign(__assign({}, d), {
          key: key,
          isParent: isParent,
          disabled: disabled
        });
      } else {
        return __assign(__assign({}, d), {
          key: key,
          isParent: isParent,
          disabled: disabled,
          children: loop(d.children, key, disabled)
        });
      }
    });
    return expandedate;
  };

  var newData = loop(data, 0, false);
  return newData;
};

var setDefaultExpandedNode = function setDefaultExpandedNode(item) {
  if (item && item.parent) {
    item.parent.open = true;
    setDefaultExpandedNode(item.parent);
  }
};
/**
 * 展开树对象
 * @param treeData
 */


function flatternTree(treeData, parent) {
  if (parent === void 0) {
    parent = null;
  }

  return treeData.reduce(function (prev, curr) {
    if (!curr.children) {
      return __spreadArrays(prev, [__assign(__assign({}, curr), {
        parent: parent
      })]);
    } else {
      var children = curr.children,
          rest = __rest(curr, ["children"]);

      return __spreadArrays(prev, [__assign(__assign({}, rest), {
        parent: parent
      })], flatternTree(children, curr.key));
    }
  }, []);
}
/**
 * 判断是否是叶子节点
 * @param {*} treeData
 * @param {*} key
 */


function isLeaf(nodeArray, key) {
  return !nodeArray.find(function (node) {
    return node.parent === key;
  });
}
/**
 * 查找兄弟节点 不包括自身
 * @param {*} nodeArray
 * @param {*} key
 */
// function findSiblings(nodeArray: Node[], key: string) {
//   const keyNode = nodeArray.find(node => node.key === key);
//   return nodeArray.filter(
//     (node) => node.parent === keyNode?.parent && node.key !== key
//   );
// }

/**
 * 查找父亲节点
 * @param {*} nodeArray
 * @param {*} key
 */
// function findParent(nodeArray: Node[], key) {
//   const keyNode = nodeArray.find((node) => node.key === key);
//   return nodeArray.find((node) => node.key === keyNode?.parent);
// }


function findPathToRoot(nodeArray, key) {
  var path = [];
  var keyNode = nodeArray.find(function (node) {
    return node.key === key;
  });
  var p = keyNode;

  while (p && p.parent) {
    path.push(p.key);
    p = nodeArray.find(function (node) {
      return node.key === (p === null || p === void 0 ? void 0 : p.parent);
    });
  }

  if (p) {
    path.push(p.key);
  }

  return path;
}

function findSubTreeNode(nodeArray, key) {
  var keyNode = nodeArray.find(function (node) {
    return node.key === key;
  });

  if (isLeaf(nodeArray, key)) {
    return nodeArray.filter(function (node) {
      return node.key === key;
    });
  }

  var children = nodeArray.filter(function (node) {
    return node.parent === key;
  }); //   children.map((child) => findSubTreeNode(nodeArray, child.key));

  return children.reduce(function (prev, curr) {
    return __spreadArrays(prev, findSubTreeNode(nodeArray, curr.key));
  }, [keyNode]);
}

function isNoneChecked(nodeArray, checkedKeys) {
  return nodeArray.every(function (node) {
    return !checkedKeys.includes(node.key);
  });
}

function getCheckedKeys(nodeArray, key, checkedKeys) {
  var newCheckedKeys = checkedKeys.slice();
  var path = findPathToRoot(nodeArray, key);
  var clearedKeys = path.filter(function (nodeKey) {
    // console.log(path);
    //删除根节点
    newCheckedKeys = newCheckedKeys.filter(function (checkedKey) {
      return checkedKey !== nodeKey;
    });
    var subNodes = findSubTreeNode(nodeArray, nodeKey);
    var flag = isNoneChecked(subNodes, newCheckedKeys);

    if (flag) {
      newCheckedKeys = newCheckedKeys.filter(function (checkedKey) {
        return checkedKey !== nodeKey;
      });
    }

    return flag;
  });
  return checkedKeys.filter(function (checkedKey) {
    return !clearedKeys.includes(checkedKey);
  });
}

var useTree = function useTree(props) {
  var data = props.data,
      selected = props.selected,
      _a = props.checkedIds,
      checkedIds = _a === void 0 ? [] : _a;
  var initData = addExpandedKeys(data, selected);
  var selectedItem = getInitiSelectedItem(initData, selected);

  var _b = react_1.useState(initData),
      newData = _b[0],
      setData = _b[1]; //设置勾选的checkedKeys数组


  var _c = react_1.useState(getInitiCheckedKeys(initData, checkedIds)),
      checkedKeys = _c[0],
      setCheckedKeys = _c[1];

  var _d = react_1.useState(selectedItem && selectedItem.key),
      selectedKey = _d[0],
      setSelectedKey = _d[1]; // 删除


  var onDelete = function onDelete(key, name) {
    var selectedId = getSelectedId(key);

    if (props.onDelete) {
      props.onDelete(selectedId, name);
    }
  };

  var onSelected = function onSelected(callback, selectedKey) {
    setSelectedKey(selectedKey);
    var selectedId = getSelectedId(selectedKey);

    if (callback) {
      callback(selectedId);
    }

    if (props.onSelected) {
      props.onSelected(selectedId);
    }
  };

  var getSelectedId = function getSelectedId(key) {
    var selectedId;

    var loop = function loop(data) {
      data.forEach(function (d) {
        if (key === d.key) {
          selectedId = d.id;
        }

        if (d.children) {
          loop(d.children);
        }
      });
    };

    loop(newData);
    return selectedId;
  };

  var onChecked = function onChecked(key, parent) {
    var _checkedKeys = [];
    var allKey;

    if (parent) {
      allKey = [];

      var loop_1 = function loop_1(data) {
        data.forEach(function (d) {
          if (d.key === key) {
            allKey.push(d.key);

            var childLoop_1 = function childLoop_1(child) {
              child.forEach(function (c) {
                if (!c.disabled) {
                  allKey.push(c.key);

                  if (c.isParent) {
                    childLoop_1(c.children);
                  }
                }
              });
            };

            childLoop_1(d.children);
          } else if (d.isParent) {
            loop_1(d.children);
          }
        });
      };

      loop_1(newData);
    } else {
      allKey = key;
    }

    if (!checkedKeys.find(function (k) {
      return k === key;
    })) {
      _checkedKeys = checkedKeys.concat(allKey);

      if (parent) {
        _checkedKeys = Array.from(new Set(_checkedKeys));
      }
    } else {
      if (parent) {
        _checkedKeys = checkedKeys.filter(function (k) {
          var divi = allKey.findIndex(function (ak) {
            return ak === k;
          });
          return divi === -1;
        });
      } else {
        var nodeArray = flatternTree(newData);
        _checkedKeys = getCheckedKeys(nodeArray, key, checkedKeys);
      } //   _checkedKeys = checkedKeys.filter((k) => {
      //     if (parent) {
      //       const divi = allKey.findIndex((ak) => ak === k);
      //       return divi === -1;
      //     }
      //     return k !== allKey;
      //   });

    }

    setCheckedKeys(_checkedKeys);
    console.log("\u83B7\u53D6\u9009\u4E2D\u7684 " + _checkedKeys);
    var checkedId = getChecked(_checkedKeys).checkedId;
    var checkedName = getChecked(_checkedKeys).checkedName;

    if (props.onChecked) {
      props.onChecked(checkedId, checkedName);
    }
  }; //获取checkedIds 与 checkNames 数组


  var getChecked = function getChecked(keys) {
    var checkedId = [];
    var checkedName = [];

    var loop = function loop(data) {
      data.forEach(function (d) {
        if (keys.find(function (k) {
          return k === d.key;
        })) {
          checkedId.push(d.id);
          checkedName.push(d.name);
        }

        if (d.children) {
          loop(d.children);
        }
      });
    };

    loop(newData);
    return {
      checkedId: checkedId,
      checkedName: checkedName
    };
  };

  var onSwitch = function onSwitch(key, open) {
    var data = newData;

    var loop = function loop(data) {
      var switchOpen = data.map(function (d) {
        if (d.key === key) {
          return __assign(__assign({}, d), {
            open: open
          });
        } else if (d.isParent) {
          return __assign(__assign({}, d), {
            children: loop(d.children)
          });
        } else {
          return d;
        }
      });
      return switchOpen;
    };

    data = loop(newData);
    setData(data);
  };

  react_1.useEffect(function () {
    setData(initData);
    setCheckedKeys(getInitiCheckedKeys(initData, checkedIds));
    setSelectedKey(selectedItem && selectedItem.key);
  }, [data, selected]);
  return {
    newData: newData,
    selectedKey: selectedKey,
    checkedKeys: checkedKeys,
    onSelected: onSelected,
    onChecked: onChecked,
    onDelete: onDelete,
    onSwitch: onSwitch
  };
};

exports["default"] = useTree;