"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isEqual = exports.deepCopy = exports.compare = exports.arrayToMap = exports.objectToArray = exports.isInArray = void 0;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

/**
 * 判断数组中是否包含某个值
 *
 * @param {any} value
 * @param {any} array
 * @returns
 *
 * @memberof Tools
 */
var isInArray = function isInArray(value, array) {
  if (array.length === 0) {
    return false;
  }

  for (var i in array) {
    if (array[i] === value) {
      return true;
    }
  }

  return false;
};
/**
 * 对象转数组
 * @param  {object} data
 * @return {array}
 *
 * { a: {b: 1}, c: {d: 2}} => [{a: [{b: 1}, {b: [{d: 2}]}]}]
 */


exports.isInArray = isInArray;

var objectToArray = function objectToArray(data) {
  var res;

  if (_typeof(data) === 'object') {
    res = Object.keys(data).map(function (el) {
      var tmp = {};
      var val = data[el];
      tmp[el] = objectToArray(val);
      return tmp;
    });
  } else {
    res = data;
  }

  return res;
};
/**
 * 数组转对象
 * @param arr
 * @param key
 */


exports.objectToArray = objectToArray;

var arrayToMap = function arrayToMap(arr) {
  var key = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'id';
  return arr.reduce(function (prev, item) {
    return _objectSpread(_objectSpread({}, prev), {}, _defineProperty({}, item[key], item));
  }, {});
};
/**
 * 对象数组排序比较
 */


exports.arrayToMap = arrayToMap;

var compare = function compare(prop) {
  return function (obj1, obj2) {
    var val1 = obj1[prop];
    var val2 = obj2[prop];

    if (val1 < val2) {
      return -1;
    } else if (val1 > val2) {
      return 1;
    }

    return 0;
  };
};
/**
 * 深度拷贝
 */


exports.compare = compare;

var deepCopy = function deepCopy(o) {
  if (o instanceof Array) {
    var n = [];

    for (var i = 0; i < o.length; ++i) {
      n[i] = deepCopy(o[i]);
    }

    return n;
  } else if (o instanceof Object) {
    var obj = {};

    for (var j in o) {
      obj[j] = deepCopy(obj[j]);
    }

    return obj;
  } else {
    return o;
  }
};
/**
 * 比较数组
 */


exports.deepCopy = deepCopy;

var isEqual = function isEqual(arr1, arr2) {
  return window._.isEqual(window._.cloneDeep(arr1).sort(), window._.cloneDeep(arr2).sort());
};

exports.isEqual = isEqual;