"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatCPU = exports.bytesToMB = exports.mbToGB = exports.bytesToSize = void 0;

/**
 * 字节格式化
 * @param  {int} bytes 字节数
 * @return {string}
 */
var bytesToSize = function bytesToSize(bytes) {
  var precision = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 3;
  var k = 1024;
  var sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];

  if (bytes === 0) {
    return 0;
  }

  var i = Math.floor(Math.log(bytes) / Math.log(k));
  var size = bytes / Math.pow(k, i);

  if (this.isInteger(size)) {
    return parseInt(size) + sizes[i];
  }

  return size.toPrecision(precision) + sizes[i];
};
/**
 * mb转gb
 */


exports.bytesToSize = bytesToSize;

var mbToGB = function mbToGB(mb) {
  if (mb) {
    return parseInt(mb / 1024);
  }

  return 0;
};
/**
 * bytes转mb
 */


exports.mbToGB = mbToGB;

var bytesToMB = function bytesToMB(bytes) {
  if (bytes === 0) {
    return 0;
  }

  var result = (bytes / Math.pow(1024, 2)).toFixed(2);

  if (result === 0) {
    return 0;
  }

  return result;
};
/**
 * 格式化cpu单位
 */


exports.bytesToMB = bytesToMB;

var formatCPU = function formatCPU(ram) {
  if (ram < 1024) {
    return "".concat(ram, "M");
  }

  var ramInfo = parseInt(ram) % 1024 === 0 ? parseInt(ram) / 1024 : (parseInt(ram) / 1024).toFixed(1);
  return "".concat(ramInfo, "G");
};

exports.formatCPU = formatCPU;